docstripy.rest
==============

docstripy.rest.build\_doc
-------------------------

.. automodule:: docstripy.rest.build_doc
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.rest.parse\_doc
-------------------------

.. automodule:: docstripy.rest.parse_doc
   :members:
   :undoc-members:
   :show-inheritance:
